@@ -17,7 +17,7 @@ config etc/X11/fvwm2/system.fvwm2rc.new
 ( cd usr/X11R6/bin ; ln -sf xpmroot fvwm-root )
 ( cd usr/X11R6/lib/X11 ; rm -rf fvwm2 )
 ( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/fvwm2 fvwm2 )
-( cd usr/X11R6/man/man1 ; rm -rf fvwm-root.1 )
-( cd usr/X11R6/man/man1 ; ln -sf xpmroot.1 fvwm-root.1 )
-( cd usr/X11R6/libexec/fvwm/2.4.18 ; rm -rf FvwmAudio )
-( cd usr/X11R6/libexec/fvwm/2.4.18 ; ln -sf FvwmEvent FvwmAudio )
+( cd usr/X11R6/man/man1 ; rm -rf fvwm-root.1.gz )
+( cd usr/X11R6/man/man1 ; ln -sf xpmroot.1.gz fvwm-root.1.gz )
+( cd usr/X11R6/libexec/fvwm/2.4.19 ; rm -rf FvwmAudio )
+( cd usr/X11R6/libexec/fvwm/2.4.19 ; ln -sf FvwmEvent FvwmAudio )
